Taber, C. B., Patterson, E., Shah, J., Francis, P., & Wager, J. (2023). Validity and Reliability of a
Computer Vision System to Determine Bar Displacement and Velocity.
International Journal of Strength and Conditioning

[https://doi.org/10.47206/ijsc.v3i1.263](https://doi.org/10.47206/ijsc.v3i1.263)

# **Validity and Reliability of a** **Computer Vision System to** **Determine Bar Displacement** **and Velocity**

Christopher B. Taber \[1\], Emma Patterson \[1\], Jui Shah \[1\], Padraig Francis \[1\], & Justin Wager \[1\]

_1Department of Physical Therapy and Human Movement Science, Sacred Heart University, Fairfield, USA_

_Corresponding Author: taberc@sacredheart.edu_

**ABSTRACT**

This study examined the validity and reliability of
a video-based smartphone application (VBA) to
measure displacement and velocity in the barbell
bench press, back squat, and deadlift. Nine
resistance trained subjects (three females; six
males; age: 24.2±4.2 years; height 175.8±8.1 cm;
body mass 87.2±18.2kg) completed two test-retest
sessions for the barbell bench press, back squat,
and deadlift one week apart. Eight repetitions
were completed for the bench press, back squat,
and deadlift with a load of 40kg and completed
at fast and slow velocities. Bar displacement and
average velocity were measured simultaneously
using 3-D motion capture (MC) and a VBA. The
VBA’s validity and reliability were analyzed by
Pearson’s product-moment correlation coefficient
( _r_ ), intraclass correlation coefficient (ICC), and
Bland-Altman Plots. Displacement data showed
moderate to nearly perfect correlations ( _r_ =0.430.94) and moderate to excellent reliability (ICC=
0.67-0.98) and Bland-Altman plots revealing little
bias (\< 2cm). Average velocity data showed large to
nearly perfect correlations ( _r_ =0.67-0.95) and good
to excellent reliability (ICC= 0.79-0.94) with BlandAltman revealing little bias (\< 0.06 m/s). Taken
together the VBA examined in this study was both
valid and reliable compared with a gold standard
criterion measurement of MC. These results provide
evidence that the VBA may be used in the tracking
of displacement and average velocity in the bench
press, back squat, and deadlift at both fast and
slower movement velocities.

Keywords: Strength Training; Monitoring; Testing

**INTRODUCTION**

The tracking of barbell velocity during resistance
training (velocity-based training, VBT) has become
common practice in training of athletes. The
theory behind this method is that certain fitness
qualities (e.g., max strength, strength-speed) can
be developed by lifting various loads at particular
velocities which will drive specific adaptations (7).
There are many ways of incorporating VBT into the
development of athletes. Most commonly, VBT is
used to provide immediate feedback during training
to motivate athletes and adjust the load on the
barbell to account for fatigue (14). Immediate barbell
velocity feedback may enhance performance when
combined with training resulting in better training
results in as little as six weeks (12). Additionally,
using velocity thresholds to drive performance
has influenced strength, power, and hypertrophy
with different amounts of velocity loss (10, 15). For
these reasons, VBT may be used during training to
improve performance outcomes.

Previous investigations have examined the reliability
and validity of various VBT devices such as linear
position transducers (LPT), accelerometers, and
inertial measurements sensors (3, 11, 13, 16).
Of these, LPT devices demonstrate the highest
agreement and reliability when compared against the
gold standard measurement of 3-D motion capture
(MC) (8, 9, 16). Previously, wireless accelerometers
exhibited lower levels of agreement and reliability,

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is an
open access article distributed under the terms and conditions of the
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).

**International Journal of Strength and Conditioning. 2023**

however, limited data from newer wireless inertial
measurement sensors have revealed that they may
be more valid and reliable then previous technology
(3, 4, 8). With advances in computer vision, it may
be possible to track barbell kinematics from video,
however, fewer studies have been completed on
computer vision applications related to VBT (1, 13,
16).

In addition, new applications leveraging computer
vision are being developed and may be cost efficient
and valid tools for coaches and athletes. One
such application is Metric VBT (Core Advantage,
Melbourne, Australia), a smartphone application that
records video with the phone’s onboard camera and
utilizes computer vision to identify and track barbell
position. These new applications, while promising,
need to be analyzed for validity and reliability before
widespread adoption. Therefore, the purpose of
this study is to examine the criterion validity and
reliability between a novel video-based smartphone
application (VBA), Metric VBT, and the gold
standard measurement criterion of MC. Specifically,
this study will determine if the VBA can provide
similar measurements of mean concentric velocity
(MCV) and concentric phase range of motion (ROM)
of common strength training exercises compared to
MC.

**METHODS**

Nine resistance trained subjects (three females; six
males; age: 24.2±4.2 years; height 175.8±8.1 cm;
body mass 87.2±18.2 kg) participated in this study.
All subjects needed to be familiar with the bench,
squat, and deadlift exercises. Subjects needed to
be regularly engaged in resistance training for the
past three months to be included. Subjects needed
to be capable of lifting 40 kg for multiple sets of
eight repetitions in the three exercises. Prior to the
start of the study, subjects were informed of the
procedures, allowed to ask any clarifying questions,
and gave their written informed consent. This study
was approved by the University’s institutional review
board (IRB#220519B) and all procedures complied
with the Declaration of Helsinki.

This reliability and validation study was performed
in two sessions one week apart at approximately
the same time of the day and under the same
ambient conditions. Data from VBA was collected
simultaneously alongside MC in both sessions. To
examine VBA’s criterion validity, data from VBA was
compared to MC for each trial. To examine reliability,

**Validity and Reliability of a Computer Vision System to Determine**
**Bar Displacement and Velocity**

VBA data from the first session was compared
to the second session. During the first session,
basic demographic information was collected
alongside informed consent before the experimental
procedures. Next, subjects completed a brief body
weight general warm-up (20 jumping jacks, 10 body
weight squats, 5 lunges each leg, and 10 arm circles
forward and backward) followed by two sets of eight
repetitions for the squat, bench press, and deadlift
exercises. A 20 kg barbell (Pendlay, Nexgen) was
used with an additional 20 kg of load, totaling 40 kg
for each exercise. The first set of each exercise was
completed with a slow movement tempo. Subjects
were instructed to perform each movement with a
two second eccentric and two second concentric
tempo. The second set of each exercise was
completed with a fast movement tempo. Subjects
were instructed to control the eccentric portion and
stand up explosively as possible on the concentric
portion. In total, 48 repetitions (16 repetitions per
exercise) were collected for each subject with 24
fast and 24 slow trials. Approximately seven days
later, the subjects reported back to the lab to
complete the second collection day (an additional
48 repetitions per subject) with the exact same order
of procedures as week one.

_Data collection_

Videos for the VBA were captured using the onboard
camera of a tablet (iPad Pro, Apple, CA, USA). The
tablet was oriented vertically for all data collection
and mounted on a tripod for stability. The device
was placed 2.5m from the end sleeve of the barbell
and fixed at a height of 99.0 cm. All data were
collected with a resolution of 1080p and a sampling
rate of 60 Hz. Videos were collected and analyzed
by the MetricVBT application (version 0.5.4) which
calculated the range of motion (ROM) and mean
concentric velocity (MCV) for each repetition.

For the motion capture data, a reflective marker
was placed on the center of the end of the barbell
sleeve. Marker positions were collected using 14
Vicon Vero cameras (Vicon Motion Systems Ltd,
Oxford, UK) at a frequency of 240Hz. The MC
data were filtered with a second-order recursive
lowpass Butterworth filter with a cutoff frequency
of 10 Hz. The concentric phase of each repetition
was then identified as the period of positive vertical
bar velocity, as defined by negative-to-positive
zero-crossings of the bar’s vertical velocity. ROM
was calculated as the vertical displacement of the
barbell between the start and end of the concentric
phase. MCV was calculated as the barbell’s mean

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is an **2**
open access article distributed under the terms and conditions of the
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).

**International Journal of Strength and Conditioning. 2023** **Taber, C. B., Patterson, E., Shah, J., Francis, P., & Wager, J.**

vertical velocity during the concentric phase. All MC
data analysis was performed in MATLAB R2020b
(Version 9.9.0.1495850, The MathWorks, Natick,
MA, USA) for analysis

Data was assessed for normality using the ShapiroWilks test. Mean and standard deviations were
calculated for descriptive statistics. To determine
the relationship between the VBA and the MC, a
Pearson’s zero-order product-moment correlation
was used with 95% confidence intervals and linear
regression. Correlation values were interpreted with a
scale by Hopkins as 0.0-01, 0.1-0.3, 0.3-0.5, 0.5-0.7,
0.7-0.9, and 0.9-1.0 and interpreted by descriptors
of trivial, small, moderate, large, very large, and
nearly perfect (5). Reliability was assessed by
using a 2-way mixed effect, single-rater, intraclass
correlation coefficient (ICC), and coefficient of
variation (CV). Intraclass correlation coefficient
values were interpreted as poor, moderate, good, or
excellent based on scale by Koo and Li as 0.50, 0.50–
0.74, 0.75–0.90, or 9.0, respectively (6). Accepted
within-session variability was classified as \<10%
(2). Bland-Altman plots and CV were calculated in
a custom Excel sheet (Version 2019, Microsoft, WA).
All statistical analyses were performed with JASP
(version 0.11.1, Amsterdam, NL), using _p_ ≤ 0.05 as
standard statistical significance.

**RESULTS**

All data was normally distributed. A total of 864
repetitions were analyzed. Reliability data for MCV
can be found in Table 1 and for ROM in Table 2. ICC

and CV data for MCV showed moderate to excellent
reliability on slow repetitions of squat, bench press,
deadlift, and good reliability on fast repetitions of
squat, bench press, deadlift. ICC and CV data for
ROM showed good reliability on slow repetitions of
squat, bench press, deadlift and excellent reliability
on fast repetitions of squat, bench press, and
deadlift.

Descriptive data and Pearson correlation coefficients
for MCV can be found in Table 1 and ROM can be
found in Table 2. Significant correlations were found
between VBA and MC for both ROM and MVC on
slow and fast repetitions. Bland-Altman plots for
ROM can be found in Figure 1 and MCV in Figure 2.
For MCV, biases for squat, bench press, and deadlift
were all less than 0.06 m/s. Bias in ROM was largest
for the bench press and deadlift exercises at fast
and slow repetitions, with the highest bias being just
over 2 cm.

**DISCUSSION**

The purpose of this study was to examine the
criterion validity and reliability between VBA and
MC. The data indicate that the VBA is moderately
to nearly perfectly correlated to MC for ROM and
demonstrated large to nearly perfect for MCV across
fast and slow movements in the squat, bench press,
and deadlift. Additionally, the device expressed
good to excellent reliability for both slow and fast
repetitions. Bias was present in ROM measurements
of the bench and deadlift, where the VBA tended
to underestimate the ROM compared to MC during

**Table 1.**
Descriptive data, correlation coefficients, and intraclass correlations between motion capture and video-based phone application for barbell displacement.

**95% CI** **ICC**
**Exercise** **Speed** **ROM (cm)** _**r**_ **ICC** **CV (%)**
**for** _**r**_ **Descriptor**

VBA: 61.8 ± 5.8
Squat Slow 0.94\* 0.91 - 0.96 0.98 11.1 Excellent
MC: 63.1 ± 6.1

VBA: 37.4 ± 2.8
Bench Press Slow 0.43\* 0.29 - 0.55 0.67 7.6 Moderate
MC: 40.0 ± 3.0

VBA: 51.3 ± 3.7
Deadlift Slow 0.70\* 0.61 - 0.78 0.76 6.4 Good
MC: 54.6 ± 3.0

VBA: 62.9 ± 5.3
Squat Fast 0.75\* 0.66 - 0.81 0.89 8.9 Good
MC: 63.7 ± 6.0

VBA: 38.4 ± 3.5
Bench Press Fast 0.73\* 0.65 - 0.80 0.80 9.2 Good
MC: 41.7 ± 3.9

VBA: 54.3 ± 5.0
Deadlift Fast 0.77\* 0.70 - 0.83 0.84 8.0 Good
MC: 57.6 ± 3.9

_ICC = Interclass Correlation Coefficient; CV = coefficient of variation_

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is anopen access article distributed under the terms and conditions of the **3**
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).

**International Journal of Strength and Conditioning. 2023**

**Validity and Reliability of a Computer Vision System to Determine**
**Bar Displacement and Velocity**

**Table 2.**
Descriptive data, correlation coefficients, and intraclass correlations between motion capture and video-based phone application for barbell mean concentric velocity.

**95% CI** **ICC**
**Exercise** **Speed** **MCV (m/s)** _**r**_ **ICC** **CV (%)**
**for** _**r**_ **Descriptor**

VBA: 0.52 ± 0.10
Squat Slow 0.81\* 0.74 - 0.86 0.87 22.2 Good
MC: 0.45 ± 0.11

VBA: 0.43 ± 0.11
Bench Press Slow 0.67\* 0.57 - 0.75 0.79 24.4 Good
MC: 0.35 ± 0.08

VBA: 0.49 ± 0.09
Deadlift Slow 0.77\* 0.69 - 0.83 0.87 18.8 Good
MC: 0.44 ± 0.08

VBA: 0.86 ± 0.23
Squat Fast 0.95\* 0.94 - 0.97 0.98 25.8 Excellent
MC: 0.83 ± 0.21

VBA: 0.77 ± 0.23
Bench Press Fast 0.87\* 0.82 - 0.90 0.94 30.0 Excellent
MC: 0.74 ± 0.21

VBA 0.85 ± 0.23
Deadlift Fast 0.86\* 0.81 - 0.90 0.94 26.0 Excellent
MC: 0.82 ± 0.20

_ICC = Interclass Correlation Coefficient; CV = coefficient of variation_

**Figure 1.** Bland-Altman analysis for displacement with limits of agreement (± 1.96 SD)

bench press and deadlift for both slow and fast
repetitions. Very little bias was present for MCV
for measurements compared to MC. Overall, the
data indicate that the VBA is both reliable and valid
across a range of common exercises and velocities
compared with the gold standard criterion of MC.

The main outcome from this study suggests that
compared to the criterion (MC), the VBA provided
a valid measure of ROM and MCV during three
resistance training exercises at two velocities.
These values are similar to values obtained in

other studies examining mobile phone and tablet

application (16). In contrast, the CVs in this study
were acceptable for ROM with only the fast squat
falling outside the acceptable range (>10%) (16).
Compared to other studies using MCV tracking the
CVs in this study fell outside the acceptable range
(16). Overall, fast repetitions tended to have higher
correlation values compared to the slower variables
in both the ROM and MCV. When examining each
exercise individually, squats presented the highest
correlation values in both ROM and MCV. Deadlifts
and bench press tended to have lower correlation
values on both ROM and MCV. With the exception of
the bench press, which had a moderate correlation

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is an **4**
open access article distributed under the terms and conditions of the
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).

**International Journal of Strength and Conditioning. 2023** **Taber, C. B., Patterson, E., Shah, J., Francis, P., & Wager, J.**

**Figure 2.** Bland-Altman analysis for mean concentric velocity with limits of agreement (± 1.96 SD)

for ROM (0.43), all other variables demonstrated
large to nearly perfect correlation values.

The between-day reliability values obtained in
this study were good to excellent for all exercises
for both ROM and MCV with the exception of the
bench press ROM. Squats presented the highest
reliability for ROM (ICC = 0.98) and MCV (ICC =
0.98) followed by deadlift and finally bench press.
The MCV measurements tended to have higher ICC
values across all metrics (0.79-0.98) compared to
ROM measurement (0.67-0.98). Squats which had
the largest ROM also had the highest reliability
values in the study. Finally, in both ROM and MCV
the faster repetitions tended to produce higher
reliability values compared to slow repetitions.

While validity compared to MC was strong for VBA,
the results could have been affected by differences
in analysis choices between our custom software
and Metric VBT, such as filter design and cutoff
frequency and the method for identifying the
concentric phase. ROM should be particularly
sensitive to the filter’s cutoff frequency as it is
calculated from the minima and maxima of bar
displacement. Slower movements tended to have
less distinct peaks in the displacement data than
faster movements and occasionally had multiple
zero crossings in the velocity data. To detect the
end of the concentric phase, the first zero crossing

in the velocity data for each repetition was used. As
the VBA may have employed a different strategy to
solve this issue, VBA and MC may not have been
detecting the exact same point as the end of the
concentric phase of each rep. This could have led
to the lower correlations generally found for slow
movements compared to fast movements.

This study is not without limitations. First, the weight
used in this study was fixed. It is unknown if lifting
heavier weights, closer to a subject’s maximum
would affect the outcomes. Both fast and slow

repetitions were completed so it should not alter the
outcomes but it was not tested. Next, the exercises
in this study were all linear in nature. Changes may
occur if the bar is lifted in a curvilinear motion based

on how the VBA calculates variables and detects
the start and ends of the motion. Finally, only three
exercises were tested in this study and it is unclear if
other movements with different executions will have

the same reliability and validity.

In conclusion, this investigation provides another tool
which coaches can use to track and monitor barbell
kinematics for their athletes. Analysis revealed
moderate to nearly perfect correlations for MCV
and ROM.  Previously, wireless sensors have been
less valid and reliable compared to LPT for tracking
common strength movements (8). However, newer
technology such as computer vision and inertial

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is anopen access article distributed under the terms and conditions of the **5**
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).

**International Journal of Strength and Conditioning. 2023**

movement sensors have established some initial
promise in being both reliable and valid against MC
in common exercises (3).

**PRACTICAL APPLICATIONS**

This investigation revealed that VBA is a valid and
reliable measurement tool in the measurement of
MCV and ROM. This new VBA provides coaches
with a low-cost, simple, phone-based application
which can be used for VBT. Future studies should
investigate the validity and reliability of this VBA and
its use for monitoring and tracking peak power and
range of motion in explosive movements such as the
snatch and clean and jerk which are widely used in
field of strength and conditioning.

**REFERENCES**

1. Balsalobre-Fernández C, Marchante D, Baz-Valle
   E, Alonso-Molero I, Jiménez SL, and Muñóz-López
   M. Analysis of wearable and smartphone-based
   technologies for the measurement of barbell velocity
   in different resistance training exercises. Frontiers in
   physiology: 649, 2017.
1. Cormack SJ, Newton RU, McGuigan MR, and Doyle
   TL. Reliability of measures obtained during single
   and repeated countermovement jumps. International
   journal of sports physiology and performance 3: 131144, 2008.
1. Feuerbacher JF, Jacobs MW, Dragutinovic B,
   Goldmann J-P, Cheng S, and Schumann M. Validity
   and test-retest reliability of the Vmaxpro sensor for
   evaluation of movement velocity in the deep squat.
   Journal of Strength and Conditioning Research 37:
   35-40, 2023.
1. Fritschi R, Seiler J, and Gross M. Validity and effects
   of placement of velocity-based training devices.
   Sports 9: 123, 2021.
1. Hopkins WG. Correlation coefficient: a new view of
   statistics. Recuperado de: <http://www> sportsci org/
   resource/stats/correl html, 2000.
1. Koo TK and Li MY. A guideline of selecting and
   reporting intraclass correlation coefficients for
   reliability research. Journal of chiropractic medicine
   15: 155-163, 2016.
1. Mann B. Developing explosive athletes: Use of
   velocity based training in athletes. Ultimate Athlete
   Concepts, 2016.
1. Orange ST, Metcalfe JW, Liefeith A, Marshall P,
   Madden LA, Fewster CR, and Vince RV. Validity and
   reliability of a wearable inertial sensor to measure
   velocity and power in the back squat and bench press.
   The Journal of Strength & Conditioning Research 33:
   2398-2408, 2019.
1. Orange ST, Metcalfe JW, Marshall P, Vince RV,

**Validity and Reliability of a Computer Vision System to Determine**
**Bar Displacement and Velocity**

Madden LA, and Liefeith A. Test-retest reliability of
a commercial linear position transducer (GymAware
PowerTool) to measure velocity and power in the
back squat and bench press. The Journal of Strength
& Conditioning Research 34: 728-737, 2020.
10\. Pareja‐Blanco F, Rodríguez‐Rosell D, Sánchez‐
Medina L, Sanchis‐Moysi J, Dorado C, Mora‐Custodio
R, Yáñez‐García JM, Morales‐Alamo D, Pérez‐
Suárez I, and Calbet J. Effects of velocity loss during
resistance training on athletic performance, strength
gains and muscle adaptations. Scandinavian journal
of medicine & science in sports 27: 724-735, 2017.
11\. Perez-Castilla A, Piepoli A, Delgado-García G,
Garrido-Blanca G, and García-Ramos A. Reliability
and concurrent validity of seven commercially
available devices for the assessment of movement
velocity at different intensities during the bench press.
The Journal of Strength & Conditioning Research 33:
1258-1265, 2019.
12\. Randell AD, Cronin JB, Keogh JW, Gill ND, and
Pedersen MC. Effect of instantaneous performance
feedback during 6 weeks of velocity-based resistance
training on sport-specific performance tests. The
Journal of Strength & Conditioning Research 25: 8793, 2011.
13\. Thompson SW, Rogerson D, Dorrell HF, Ruddock A,
and Barnes A. The reliability and validity of current
technologies for measuring barbell velocity in the
free-weight back squat and power clean. Sports 8:
94, 2020.
14\. Weakley J, Mann B, Banyard H, McLaren S, Scott T,
and Garcia-Ramos A. Velocity-based training: From
theory to application. Strength & Conditioning Journal
43: 31-49, 2021.
15\. Weakley J, McLaren S, Ramirez-Lopez C, GarcíaRamos A, Dalton-Barron N, Banyard H, Mann B,
Weaving D, and Jones B. Application of velocity loss
thresholds during free-weight resistance training:
Responses and reproducibility of perceptual,
metabolic, and neuromuscular outcomes. Journal of
Sports Sciences 38: 477-485, 2020.
16\. Weakley J, Morrison M, García-Ramos A, Johnston R,
James L, and Cole MH. The validity and reliability of
commercially available resistance training monitoring
devices: a systematic review. Sports medicine 51:
443-502, 2021.

Copyright: © 2023 by the authors. Licensee IUSCA, London, UK. This article is anopen access article distributed under the terms and conditions of the **6**
Creative Commons Attribution (CC BY) license (https:// creativecommons.org/licenses/by/ 4.0/).
